@@ -115,7 +115,7 @@ BOOST_AUTO_TEST_CASE( extract_token ) {
     BOOST_CHECK( ret.second == d1.begin()+3 );
 
     ret = websocketpp::http::parser::extract_token(d2.begin(),d2.end());
-    BOOST_CHECK( ret.first == "" );
+    BOOST_CHECK( ret.first.empty() );
     BOOST_CHECK( ret.second == d2.begin()+0 );
 
     ret = websocketpp::http::parser::extract_token(d2.begin()+1,d2.end());
@@ -127,7 +127,7 @@ BOOST_AUTO_TEST_CASE( extract_quoted_string ) {
     std::string d1 = "\"foo\"";
     std::string d2 = "\"foo\\\"bar\\\"baz\"";
     std::string d3 = "\"foo\"     ";
-    std::string d4 = "";
+    std::string d4;
     std::string d5 = "foo";
 
     std::pair<std::string,std::string::const_iterator> ret;
@@ -147,11 +147,11 @@ BOOST_AUTO_TEST_CASE( extract_quoted_string ) {
     BOOST_CHECK( ret.second == d3.begin()+5 );
 
     ret = extract_quoted_string(d4.begin(),d4.end());
-    BOOST_CHECK( ret.first == "" );
+    BOOST_CHECK( ret.first.empty() );
     BOOST_CHECK( ret.second == d4.begin() );
 
     ret = extract_quoted_string(d5.begin(),d5.end());
-    BOOST_CHECK( ret.first == "" );
+    BOOST_CHECK( ret.first.empty() );
     BOOST_CHECK( ret.second == d5.begin() );
 }
 
@@ -185,7 +185,7 @@ BOOST_AUTO_TEST_CASE( extract_all_lws ) {
 }
 
 BOOST_AUTO_TEST_CASE( extract_attributes_blank ) {
-    std::string s = "";
+    std::string s;
 
     websocketpp::http::attribute_list a;
     std::string::const_iterator it;
@@ -209,7 +209,7 @@ BOOST_AUTO_TEST_CASE( extract_attributes_simple ) {
 }
 
 BOOST_AUTO_TEST_CASE( extract_parameters ) {
-    std::string s1 = "";
+    std::string s1;
     std::string s2 = "foo";
     std::string s3 = " foo \r\nAbc";
     std::string s4 = "  \r\n   foo  ";
@@ -365,6 +365,7 @@ BOOST_AUTO_TEST_CASE( strip_lws ) {
     std::string test6 = "  \r\n  foo     ";
     std::string test7 = "  \t  foo     ";
     std::string test8 = "  \t       ";
+    std::string test9 = " \n\r";
 
     BOOST_CHECK_EQUAL( websocketpp::http::parser::strip_lws(test1), "foo" );
     BOOST_CHECK_EQUAL( websocketpp::http::parser::strip_lws(test2), "foo" );
@@ -374,6 +375,7 @@ BOOST_AUTO_TEST_CASE( strip_lws ) {
     BOOST_CHECK_EQUAL( websocketpp::http::parser::strip_lws(test6), "foo" );
     BOOST_CHECK_EQUAL( websocketpp::http::parser::strip_lws(test7), "foo" );
     BOOST_CHECK_EQUAL( websocketpp::http::parser::strip_lws(test8), "" );
+    BOOST_CHECK_EQUAL( websocketpp::http::parser::strip_lws(test9), "" );
 }
 
 BOOST_AUTO_TEST_CASE( case_insensitive_headers ) {
@@ -408,7 +410,7 @@ BOOST_AUTO_TEST_CASE( case_insensitive_headers_overwrite ) {
 BOOST_AUTO_TEST_CASE( blank_consume ) {
     websocketpp::http::parser::request r;
 
-    std::string raw = "";
+    std::string raw;
 
     bool exception = false;
 
@@ -559,6 +561,30 @@ BOOST_AUTO_TEST_CASE( trailing_body_characters ) {
     BOOST_CHECK( r.get_header("Host") == "www.example.com" );
 }
 
+BOOST_AUTO_TEST_CASE( trailing_body_characters_beyond_max_lenth ) {
+    websocketpp::http::parser::request r;
+
+    std::string raw = "GET / HTTP/1.1\r\nHost: www.example.com\r\n\r\n";
+    raw.append(websocketpp::http::max_header_size,'*');
+
+    bool exception = false;
+    size_t pos = 0;
+
+    try {
+        pos = r.consume(raw.c_str(),raw.size());
+    } catch (...) {
+        exception = true;
+    }
+
+    BOOST_CHECK( exception == false );
+    BOOST_CHECK( pos == 41 );
+    BOOST_CHECK( r.ready() == true );
+    BOOST_CHECK( r.get_version() == "HTTP/1.1" );
+    BOOST_CHECK( r.get_method() == "GET" );
+    BOOST_CHECK( r.get_uri() == "/" );
+    BOOST_CHECK( r.get_header("Host") == "www.example.com" );
+}
+
 BOOST_AUTO_TEST_CASE( basic_split1 ) {
     websocketpp::http::parser::request r;
 
@@ -614,7 +640,8 @@ BOOST_AUTO_TEST_CASE( basic_split2 ) {
 BOOST_AUTO_TEST_CASE( max_header_len ) {
     websocketpp::http::parser::request r;
 
-    std::string raw(websocketpp::http::max_header_size+1,'*');
+    std::string raw(websocketpp::http::max_header_size-1,'*');
+    raw += "\r\n";
 
     bool exception = false;
     size_t pos = 0;
@@ -922,6 +949,62 @@ BOOST_AUTO_TEST_CASE( wikipedia_example_response ) {
     BOOST_CHECK_EQUAL( r.get_header("Sec-WebSocket-Protocol"), "chat" );
 }
 
+BOOST_AUTO_TEST_CASE( wikipedia_example_response_trailing ) {
+    websocketpp::http::parser::response r;
+
+    std::string raw = "HTTP/1.1 101 Switching Protocols\r\nUpgrade: websocket\r\nConnection: Upgrade\r\nSec-WebSocket-Accept: HSmrc0sMlYUkAGmm5OPpG2HaGWk=\r\nSec-WebSocket-Protocol: chat\r\n\r\n";
+    raw += "a";
+
+    bool exception = false;
+    size_t pos = 0;
+
+    try {
+        pos += r.consume(raw.c_str(),raw.size());
+    } catch (std::exception &e) {
+        exception = true;
+        std::cout << e.what() << std::endl;
+    }
+
+    BOOST_CHECK( exception == false );
+    BOOST_CHECK_EQUAL( pos, 159 );
+    BOOST_CHECK( r.headers_ready() == true );
+    BOOST_CHECK_EQUAL( r.get_version(), "HTTP/1.1" );
+    BOOST_CHECK_EQUAL( r.get_status_code(), websocketpp::http::status_code::switching_protocols );
+    BOOST_CHECK_EQUAL( r.get_status_msg(), "Switching Protocols" );
+    BOOST_CHECK_EQUAL( r.get_header("Upgrade"), "websocket" );
+    BOOST_CHECK_EQUAL( r.get_header("Connection"), "Upgrade" );
+    BOOST_CHECK_EQUAL( r.get_header("Sec-WebSocket-Accept"), "HSmrc0sMlYUkAGmm5OPpG2HaGWk=" );
+    BOOST_CHECK_EQUAL( r.get_header("Sec-WebSocket-Protocol"), "chat" );
+}
+
+BOOST_AUTO_TEST_CASE( wikipedia_example_response_trailing_large ) {
+    websocketpp::http::parser::response r;
+
+    std::string raw = "HTTP/1.1 101 Switching Protocols\r\nUpgrade: websocket\r\nConnection: Upgrade\r\nSec-WebSocket-Accept: HSmrc0sMlYUkAGmm5OPpG2HaGWk=\r\nSec-WebSocket-Protocol: chat\r\n\r\n";
+    raw.append(websocketpp::http::max_header_size,'*');
+
+    bool exception = false;
+    size_t pos = 0;
+
+    try {
+        pos += r.consume(raw.c_str(),raw.size());
+    } catch (std::exception &e) {
+        exception = true;
+        std::cout << e.what() << std::endl;
+    }
+
+    BOOST_CHECK( exception == false );
+    BOOST_CHECK_EQUAL( pos, 159 );
+    BOOST_CHECK( r.headers_ready() == true );
+    BOOST_CHECK_EQUAL( r.get_version(), "HTTP/1.1" );
+    BOOST_CHECK_EQUAL( r.get_status_code(), websocketpp::http::status_code::switching_protocols );
+    BOOST_CHECK_EQUAL( r.get_status_msg(), "Switching Protocols" );
+    BOOST_CHECK_EQUAL( r.get_header("Upgrade"), "websocket" );
+    BOOST_CHECK_EQUAL( r.get_header("Connection"), "Upgrade" );
+    BOOST_CHECK_EQUAL( r.get_header("Sec-WebSocket-Accept"), "HSmrc0sMlYUkAGmm5OPpG2HaGWk=" );
+    BOOST_CHECK_EQUAL( r.get_header("Sec-WebSocket-Protocol"), "chat" );
+}
+
 BOOST_AUTO_TEST_CASE( response_with_non_standard_lws ) {
     websocketpp::http::parser::response r;
 
