@@ -117,7 +117,7 @@ struct stub_con : public iostream_con {
         indef_read_size = num_bytes;
         indef_read_buf = buf;
         indef_read_len = len;
-        
+
         indef_read();
     }
 
@@ -138,10 +138,24 @@ struct stub_con : public iostream_con {
     void handle_indef(websocketpp::lib::error_code const & e, size_t amt_read) {
         ec = e;
         indef_read_total += amt_read;
-        
+
         indef_read();
     }
 
+    void shutdown() {
+        iostream_con::async_shutdown(
+            websocketpp::lib::bind(
+                &stub_con::handle_async_shutdown,
+                type::get_shared(),
+                websocketpp::lib::placeholders::_1
+            )
+        );
+    }
+
+    void handle_async_shutdown(websocketpp::lib::error_code const & e) {
+        ec = e;
+    }
+
     websocketpp::lib::error_code ec;
     size_t indef_read_size;
     char * indef_read_buf;
@@ -156,11 +170,11 @@ config::elog_type elogger;
 BOOST_AUTO_TEST_CASE( const_methods ) {
     iostream_con::ptr con(new iostream_con(true,alogger,elogger));
 
-    BOOST_CHECK( con->is_secure() == false );
-    BOOST_CHECK( con->get_remote_endpoint() == "iostream transport" );
+    BOOST_CHECK( !con->is_secure() );
+    BOOST_CHECK_EQUAL( con->get_remote_endpoint(), "iostream transport" );
 }
 
-BOOST_AUTO_TEST_CASE( write_before_ostream_set ) {
+BOOST_AUTO_TEST_CASE( write_before_output_method_set ) {
     stub_con::ptr con(new stub_con(true,alogger,elogger));
 
     con->write("foo");
@@ -168,10 +182,10 @@ BOOST_AUTO_TEST_CASE( write_before_ostream_set ) {
 
     std::vector<websocketpp::transport::buffer> bufs;
     con->write(bufs);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::transport::iostream::error::output_stream_required) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::transport::iostream::error::output_stream_required) );
 }
 
-BOOST_AUTO_TEST_CASE( async_write ) {
+BOOST_AUTO_TEST_CASE( async_write_ostream ) {
     stub_con::ptr con(new stub_con(true,alogger,elogger));
 
     std::stringstream output;
@@ -181,10 +195,52 @@ BOOST_AUTO_TEST_CASE( async_write ) {
     con->write("foo");
 
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( output.str() == "foo" );
+    BOOST_CHECK_EQUAL( output.str(), "foo" );
 }
 
-BOOST_AUTO_TEST_CASE( async_write_vector_0 ) {
+websocketpp::lib::error_code write_handler(std::string & o, websocketpp::connection_hdl, char const * buf, size_t len) {
+    o += std::string(buf,len);
+    return websocketpp::lib::error_code();
+}
+
+websocketpp::lib::error_code vector_write_handler(std::string & o, websocketpp::connection_hdl, std::vector<websocketpp::transport::buffer> const & bufs) {
+    std::vector<websocketpp::transport::buffer>::const_iterator it;
+    for (it = bufs.begin(); it != bufs.end(); it++) {
+        o += std::string((*it).buf, (*it).len);
+    }
+
+    return websocketpp::lib::error_code();
+}
+
+websocketpp::lib::error_code write_handler_error(websocketpp::connection_hdl, char const *, size_t) {
+    return make_error_code(websocketpp::transport::error::general);
+}
+
+BOOST_AUTO_TEST_CASE( async_write_handler ) {
+    stub_con::ptr con(new stub_con(true,alogger,elogger));
+    std::string output;
+
+    con->set_write_handler(websocketpp::lib::bind(
+        &write_handler,
+        websocketpp::lib::ref(output),
+        websocketpp::lib::placeholders::_1,
+        websocketpp::lib::placeholders::_2,
+        websocketpp::lib::placeholders::_3
+    ));
+    con->write("foo");
+    BOOST_CHECK( !con->ec );
+    BOOST_CHECK_EQUAL(output, "foo");
+}
+
+BOOST_AUTO_TEST_CASE( async_write_handler_error ) {
+    stub_con::ptr con(new stub_con(true,alogger,elogger));
+
+    con->set_write_handler(&write_handler_error);
+    con->write("foo");
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::transport::error::general) );
+}
+
+BOOST_AUTO_TEST_CASE( async_write_vector_0_ostream ) {
     std::stringstream output;
 
     stub_con::ptr con(new stub_con(true,alogger,elogger));
@@ -195,10 +251,31 @@ BOOST_AUTO_TEST_CASE( async_write_vector_0 ) {
     con->write(bufs);
 
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( output.str() == "" );
+    BOOST_CHECK_EQUAL( output.str(), "" );
 }
 
-BOOST_AUTO_TEST_CASE( async_write_vector_1 ) {
+BOOST_AUTO_TEST_CASE( async_write_vector_0_write_handler ) {
+    std::string output;
+
+    stub_con::ptr con(new stub_con(true,alogger,elogger));
+
+    con->set_write_handler(websocketpp::lib::bind(
+        &write_handler,
+        websocketpp::lib::ref(output),
+        websocketpp::lib::placeholders::_1,
+        websocketpp::lib::placeholders::_2,
+        websocketpp::lib::placeholders::_3
+    ));
+
+    std::vector<websocketpp::transport::buffer> bufs;
+
+    con->write(bufs);
+
+    BOOST_CHECK( !con->ec );
+    BOOST_CHECK_EQUAL( output, "" );
+}
+
+BOOST_AUTO_TEST_CASE( async_write_vector_1_ostream ) {
     std::stringstream output;
 
     stub_con::ptr con(new stub_con(true,alogger,elogger));
@@ -213,10 +290,34 @@ BOOST_AUTO_TEST_CASE( async_write_vector_1 ) {
     con->write(bufs);
 
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( output.str() == "foo" );
+    BOOST_CHECK_EQUAL( output.str(), "foo" );
 }
 
-BOOST_AUTO_TEST_CASE( async_write_vector_2 ) {
+BOOST_AUTO_TEST_CASE( async_write_vector_1_write_handler ) {
+    std::string output;
+
+    stub_con::ptr con(new stub_con(true,alogger,elogger));
+    con->set_write_handler(websocketpp::lib::bind(
+        &write_handler,
+        websocketpp::lib::ref(output),
+        websocketpp::lib::placeholders::_1,
+        websocketpp::lib::placeholders::_2,
+        websocketpp::lib::placeholders::_3
+    ));
+
+    std::vector<websocketpp::transport::buffer> bufs;
+
+    std::string foo = "foo";
+
+    bufs.push_back(websocketpp::transport::buffer(foo.data(),foo.size()));
+
+    con->write(bufs);
+
+    BOOST_CHECK( !con->ec );
+    BOOST_CHECK_EQUAL( output, "foo" );
+}
+
+BOOST_AUTO_TEST_CASE( async_write_vector_2_ostream ) {
     std::stringstream output;
 
     stub_con::ptr con(new stub_con(true,alogger,elogger));
@@ -233,7 +334,58 @@ BOOST_AUTO_TEST_CASE( async_write_vector_2 ) {
     con->write(bufs);
 
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( output.str() == "foobar" );
+    BOOST_CHECK_EQUAL( output.str(), "foobar" );
+}
+
+BOOST_AUTO_TEST_CASE( async_write_vector_2_write_handler ) {
+    std::string output;
+
+    stub_con::ptr con(new stub_con(true,alogger,elogger));
+    con->set_write_handler(websocketpp::lib::bind(
+        &write_handler,
+        websocketpp::lib::ref(output),
+        websocketpp::lib::placeholders::_1,
+        websocketpp::lib::placeholders::_2,
+        websocketpp::lib::placeholders::_3
+    ));
+
+    std::vector<websocketpp::transport::buffer> bufs;
+
+    std::string foo = "foo";
+    std::string bar = "bar";
+
+    bufs.push_back(websocketpp::transport::buffer(foo.data(),foo.size()));
+    bufs.push_back(websocketpp::transport::buffer(bar.data(),bar.size()));
+
+    con->write(bufs);
+
+    BOOST_CHECK( !con->ec );
+    BOOST_CHECK_EQUAL( output, "foobar" );
+}
+
+BOOST_AUTO_TEST_CASE( async_write_vector_2_vector_write_handler ) {
+    std::string output;
+
+    stub_con::ptr con(new stub_con(true,alogger,elogger));
+    con->set_vector_write_handler(websocketpp::lib::bind(
+        &vector_write_handler,
+        websocketpp::lib::ref(output),
+        websocketpp::lib::placeholders::_1,
+        websocketpp::lib::placeholders::_2
+    ));
+
+    std::vector<websocketpp::transport::buffer> bufs;
+
+    std::string foo = "foo";
+    std::string bar = "bar";
+
+    bufs.push_back(websocketpp::transport::buffer(foo.data(),foo.size()));
+    bufs.push_back(websocketpp::transport::buffer(bar.data(),bar.size()));
+
+    con->write(bufs);
+
+    BOOST_CHECK( !con->ec );
+    BOOST_CHECK_EQUAL( output, "foobar" );
 }
 
 BOOST_AUTO_TEST_CASE( async_read_at_least_too_much ) {
@@ -242,7 +394,7 @@ BOOST_AUTO_TEST_CASE( async_read_at_least_too_much ) {
     char buf[10];
 
     con->async_read_at_least(11,buf,10);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::transport::iostream::error::invalid_num_bytes) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::transport::iostream::error::invalid_num_bytes) );
 }
 
 BOOST_AUTO_TEST_CASE( async_read_at_least_double_read ) {
@@ -252,7 +404,7 @@ BOOST_AUTO_TEST_CASE( async_read_at_least_double_read ) {
 
     con->async_read_at_least(5,buf,10);
     con->async_read_at_least(5,buf,10);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::transport::iostream::error::double_read) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::transport::iostream::error::double_read) );
 }
 
 BOOST_AUTO_TEST_CASE( async_read_at_least ) {
@@ -263,32 +415,32 @@ BOOST_AUTO_TEST_CASE( async_read_at_least ) {
     memset(buf,'x',10);
 
     con->async_read_at_least(5,buf,10);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
 
     std::stringstream channel;
     channel << "abcd";
     channel >> *con;
-    BOOST_CHECK( channel.tellg() == -1 );
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( channel.tellg(), -1 );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
 
     std::stringstream channel2;
     channel2 << "e";
     channel2 >> *con;
-    BOOST_CHECK( channel2.tellg() == -1 );
+    BOOST_CHECK_EQUAL( channel2.tellg(), -1 );
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( std::string(buf,10) == "abcdexxxxx" );
+    BOOST_CHECK_EQUAL( std::string(buf,10), "abcdexxxxx" );
 
     std::stringstream channel3;
     channel3 << "f";
     channel3 >> *con;
-    BOOST_CHECK( channel3.tellg() == 0 );
+    BOOST_CHECK_EQUAL( channel3.tellg(), 0 );
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( std::string(buf,10) == "abcdexxxxx" );
+    BOOST_CHECK_EQUAL( std::string(buf,10), "abcdexxxxx" );
     con->async_read_at_least(1,buf+5,5);
     channel3 >> *con;
-    BOOST_CHECK( channel3.tellg() == -1 );
+    BOOST_CHECK_EQUAL( channel3.tellg(), -1 );
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( std::string(buf,10) == "abcdefxxxx" );
+    BOOST_CHECK_EQUAL( std::string(buf,10), "abcdefxxxx" );
 }
 
 BOOST_AUTO_TEST_CASE( async_read_at_least2 ) {
@@ -299,20 +451,20 @@ BOOST_AUTO_TEST_CASE( async_read_at_least2 ) {
     memset(buf,'x',10);
 
     con->async_read_at_least(5,buf,5);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
 
     std::stringstream channel;
     channel << "abcdefg";
     channel >> *con;
-    BOOST_CHECK( channel.tellg() == 5 );
+    BOOST_CHECK_EQUAL( channel.tellg(), 5 );
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( std::string(buf,10) == "abcdexxxxx" );
+    BOOST_CHECK_EQUAL( std::string(buf,10), "abcdexxxxx" );
 
     con->async_read_at_least(1,buf+5,5);
     channel >> *con;
-    BOOST_CHECK( channel.tellg() == -1 );
+    BOOST_CHECK_EQUAL( channel.tellg(), -1 );
     BOOST_CHECK( !con->ec );
-    BOOST_CHECK( std::string(buf,10) == "abcdefgxxx" );
+    BOOST_CHECK_EQUAL( std::string(buf,10), "abcdefgxxx" );
 }
 
 void timer_callback_stub(websocketpp::lib::error_code const &) {}
@@ -332,7 +484,7 @@ BOOST_AUTO_TEST_CASE( async_read_at_least_read_some ) {
     memset(buf,'x',10);
 
     con->async_read_at_least(5,buf,5);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
 
     char input[10] = "abcdefg";
     BOOST_CHECK_EQUAL(con->read_some(input,5), 5);
@@ -356,7 +508,7 @@ BOOST_AUTO_TEST_CASE( async_read_at_least_read_some_indef ) {
     memset(buf,'x',20);
 
     con->async_read_indef(5,buf,5);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
 
     // here we expect to return early from read some because the outstanding
     // read was for 5 bytes and we were called with 10.
@@ -365,7 +517,7 @@ BOOST_AUTO_TEST_CASE( async_read_at_least_read_some_indef ) {
     BOOST_CHECK( !con->ec );
     BOOST_CHECK_EQUAL( std::string(buf,10), "aaaaaxxxxx" );
     BOOST_CHECK_EQUAL( con->indef_read_total, 5 );
-    
+
     // A subsequent read should read 5 more because the indef read refreshes
     // itself. The new read will start again at the beginning of the buffer.
     BOOST_CHECK_EQUAL(con->read_some(input+5,5), 5);
@@ -381,7 +533,7 @@ BOOST_AUTO_TEST_CASE( async_read_at_least_read_all ) {
     memset(buf,'x',20);
 
     con->async_read_indef(5,buf,5);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
 
     char input[11] = "aaaaabbbbb";
     BOOST_CHECK_EQUAL(con->read_all(input,10), 10);
@@ -394,7 +546,7 @@ BOOST_AUTO_TEST_CASE( eof_flag ) {
     stub_con::ptr con(new stub_con(true,alogger,elogger));
     char buf[10];
     con->async_read_at_least(5,buf,5);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
     con->eof();
     BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::transport::error::eof) );
 }
@@ -403,11 +555,31 @@ BOOST_AUTO_TEST_CASE( fatal_error_flag ) {
     stub_con::ptr con(new stub_con(true,alogger,elogger));
     char buf[10];
     con->async_read_at_least(5,buf,5);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
     con->fatal_error();
     BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::transport::error::pass_through) );
 }
 
+BOOST_AUTO_TEST_CASE( shutdown ) {
+    stub_con::ptr con(new stub_con(true,alogger,elogger));
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
+    con->shutdown();
+    BOOST_CHECK_EQUAL( con->ec, websocketpp::lib::error_code() );
+}
+
+websocketpp::lib::error_code sd_handler(websocketpp::connection_hdl) {
+    return make_error_code(websocketpp::transport::error::general);
+}
+
+BOOST_AUTO_TEST_CASE( shutdown_handler ) {
+    stub_con::ptr con(new stub_con(true,alogger,elogger));
+
+    con->set_shutdown_handler(&sd_handler);
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
+    con->shutdown();
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::transport::error::general) );
+}
+
 BOOST_AUTO_TEST_CASE( shared_pointer_memory_cleanup ) {
     stub_con::ptr con(new stub_con(true,alogger,elogger));
 
@@ -416,7 +588,7 @@ BOOST_AUTO_TEST_CASE( shared_pointer_memory_cleanup ) {
     char buf[10];
     memset(buf,'x',10);
     con->async_read_at_least(5,buf,5);
-    BOOST_CHECK( con->ec == make_error_code(websocketpp::error::test) );
+    BOOST_CHECK_EQUAL( con->ec, make_error_code(websocketpp::error::test) );
     BOOST_CHECK_EQUAL(con.use_count(), 2);
 
     char input[10] = "foo";
